import { Link, Route, Routes } from "react-router-dom";
import useSWR from "swr";
import { fetchJson } from "../../../util/fetchJson.ts";
import { useAtom } from "jotai";
import { namespaceAtom } from "../../../atoms/namespace.ts";
import { Loader } from "../../../components/loader.tsx";
import { useState } from "preact/hooks";
import { NewTagModal } from "./newTagModal.tsx";

export const TagEditor = () => {
  return (
    <Routes>
      <Route index Component={TagList} />
    </Routes>
  );
};

function TagList() {
  const [namespace, _setNamespace] = useAtom(namespaceAtom);
  const { data, isLoading } = useSWR<string[]>(
    `/api/pack/${namespace}/tags`,
    fetchJson,
  );

  const [showNewTagModal, setShowNewTagModal] = useState(false);

  if (isLoading || !data) {
    return <Loader msg="Geez, when was the last time you swept?" />;
  }

  return (
    <div>
      <ul class="flex flex-col gap-2">
        <li>
          <button onClick={() => setShowNewTagModal(true)}>New Tag</button>
          {showNewTagModal && (
            <NewTagModal
              close={() => {
                setShowNewTagModal(false);
              }}
            />
          )}
        </li>
        {data.map((tag) => (
          <li class="flex gap-2">
            <Link to={`/editor/tags/${tag}`}>{tag}</Link>
            <button>Delete</button>
          </li>
        ))}
      </ul>
    </div>
  );
}
